diff --git a/java/res/layout/keyboard_popup.xml b/java/res/layout/mini_keyboard.xml
similarity index 91%
rename from java/res/layout/keyboard_popup.xml
rename to java/res/layout/mini_keyboard.xml
index e2508da78d5ce6d702c562d31bc766be4bb369e7..6964ec5d669716bebbdfdfc8fc610bf952454061 100644
--- a/java/res/layout/keyboard_popup.xml
+++ b/java/res/layout/mini_keyboard.xml
@@ -22,9 +22,9 @@
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:orientation="horizontal"
-        style="?attr/popupMiniKeyboardPanelStyle"
+        style="?attr/miniKeyboardPanelStyle"
         >
-    <com.android.inputmethod.keyboard.PopupMiniKeyboardView
+    <com.android.inputmethod.keyboard.MiniKeyboardView
             xmlns:latin="http://schemas.android.com/apk/res/com.android.inputmethod.latin"
             android:id="@+id/mini_keyboard_view"
             android:layout_alignParentBottom="true"
diff --git a/java/res/values-ar/donottranslate-altchars.xml b/java/res/values-ar/donottranslate-altchars.xml
index 0e4f265e775573154f3eb21156500027dd579e0c..6f2a3ff7d441476167aa43a97fa7ba4b93e432b7 100644
--- a/java/res/values-ar/donottranslate-altchars.xml
+++ b/java/res/values-ar/donottranslate-altchars.xml
@@ -31,7 +31,7 @@
          \u064b: ARABIC FATHATAN
          \u064d: ARABIC KASRATAN -->
     <string name="alternates_for_punctuation">"\u060c,\u061b,\u061f,!,:,-,/,\',\",\u0651,\u0652,\u064c,\u0640,\u064f,\u064e,\u0650,\u064b,\u064d"</string>
-    <integer name="popup_keyboard_column_for_punctuation">9</integer>
+    <integer name="mini_keyboard_column_for_punctuation">9</integer>
     <string name="keyhintlabel_for_punctuation">\u064b</string>
     <string name="keylabel_for_symbols_1">"Ù¡"</string>
     <string name="keylabel_for_symbols_2">"Ù¢"</string>
diff --git a/java/res/values-sw600dp/config.xml b/java/res/values-sw600dp/config.xml
index d539e0d824e4bd57d5bfff5a60754fd261730d21..17aeff7cc14f74e0ab6e30b630715f5f090b95e7 100644
--- a/java/res/values-sw600dp/config.xml
+++ b/java/res/values-sw600dp/config.xml
@@ -39,5 +39,5 @@
     <!-- This configuration is the index of the array {@link KeyboardSwitcher.KEYBOARD_THEMES}. -->
     <string name="config_default_keyboard_theme_id" translatable="false">5</string>
     <string name="config_text_size_of_language_on_spacebar" translatable="false">medium</string>
-    <integer name="config_max_popup_keyboard_column">5</integer>
+    <integer name="config_max_mini_keyboard_column">5</integer>
 </resources>
diff --git a/java/res/values-sw768dp/config.xml b/java/res/values-sw768dp/config.xml
index d8802095261eea5e07ef7500abf20c33a9cfb719..8b4ff367e9f3ef875a0c73a7e69a50089aa8f09d 100644
--- a/java/res/values-sw768dp/config.xml
+++ b/java/res/values-sw768dp/config.xml
@@ -37,7 +37,7 @@
     <!-- This configuration is the index of the array {@link KeyboardSwitcher.KEYBOARD_THEMES}. -->
     <string name="config_default_keyboard_theme_id" translatable="false">5</string>
     <string name="config_text_size_of_language_on_spacebar" translatable="false">medium</string>
-    <integer name="config_max_popup_keyboard_column">5</integer>
+    <integer name="config_max_mini_keyboard_column">5</integer>
     <!--  Screen metrics for logging. 0 = "mdpi", 1 = "hdpi", 2 = "xlarge" -->
     <integer name="log_screen_metrics">2</integer>
 </resources>
diff --git a/java/res/values/attrs.xml b/java/res/values/attrs.xml
index bc1bb080115a004cbcf53bcdc7256370ed8bf881..734004f5aba26f3d013440726c45b09f87ad3688 100644
--- a/java/res/values/attrs.xml
+++ b/java/res/values/attrs.xml
@@ -22,9 +22,9 @@
         <attr name="latinKeyboardStyle" format="reference" />
         <!-- KeyboardView style -->
         <attr name="keyboardViewStyle" format="reference" />
-        <!-- PopupMiniKeyboardView style -->
-        <attr name="popupMiniKeyboardViewStyle" format="reference" />
-        <attr name="popupMiniKeyboardPanelStyle" format="reference" />
+        <!-- MiniKeyboardView style -->
+        <attr name="miniKeyboardViewStyle" format="reference" />
+        <attr name="miniKeyboardPanelStyle" format="reference" />
         <!-- Suggestions strip style -->
         <attr name="suggestionsStripBackgroundStyle" format="reference" />
         <attr name="suggestionBackgroundStyle" format="reference" />
@@ -95,7 +95,7 @@
         <!-- Amount to offset the touch Y coordinate by, for bias correction. -->
         <attr name="verticalCorrection" format="dimension" />
 
-        <!-- Layout resource for popup keyboards. -->
+        <!-- Layout resource for popup panel -->
         <attr name="popupLayout" format="reference" />
 
         <attr name="shadowColor" format="color" />
@@ -153,8 +153,8 @@
         <attr name="horizontalGap" format="dimension|fraction" />
         <!-- Default vertical gap between rows of keys. -->
         <attr name="verticalGap" format="dimension|fraction" />
-        <!-- Popup keyboard layout template -->
-        <attr name="popupKeyboardTemplate" format="reference" />
+        <!-- Popup panel layout template -->
+        <attr name="popupTemplate" format="reference" />
         <!-- Locale of the keyboard layout -->
         <attr name="keyboardLocale" format="string" />
         <!-- True if the keyboard is Right-To-Left -->
@@ -180,8 +180,8 @@
         <attr name="code" format="integer" />
         <!-- The characters to display in the popup keyboard. -->
         <attr name="popupCharacters" format="string" />
-        <!-- Maximum column of popup keyboard -->
-        <attr name="maxPopupKeyboardColumn" format="integer" />
+        <!-- Maximum column of mini keyboard -->
+        <attr name="maxMiniKeyboardColumn" format="integer" />
         <!-- Whether this is a functional key which has different key top than normal key. -->
         <attr name="isFunctional" format="boolean" />
         <!-- Whether this is a toggle key. -->
diff --git a/java/res/values/config.xml b/java/res/values/config.xml
index 1c7c1a172a4f9ed6b4ce362d94e31a7c9c527752..28cbc95490a5ad921b424be3c4dd442f00e5daa9 100644
--- a/java/res/values/config.xml
+++ b/java/res/values/config.xml
@@ -67,7 +67,7 @@
     <!-- This configuration is the index of the array {@link KeyboardSwitcher.KEYBOARD_THEMES}. -->
     <string name="config_default_keyboard_theme_id" translatable="false">5</string>
     <string name="config_text_size_of_language_on_spacebar" translatable="false">small</string>
-    <integer name="config_max_popup_keyboard_column">5</integer>
+    <integer name="config_max_mini_keyboard_column">5</integer>
     <string-array name="auto_correction_threshold_values" translatable="false">
         <!-- Off, When auto correction setting is Off, this value is not used. -->
         <item></item>
diff --git a/java/res/values/donottranslate-altchars.xml b/java/res/values/donottranslate-altchars.xml
index acd4b3725f880b817b250b2a78247354a137f08e..acbf7dfaebec85c1371fcd8e05b1d51183754071 100644
--- a/java/res/values/donottranslate-altchars.xml
+++ b/java/res/values/donottranslate-altchars.xml
@@ -51,7 +51,7 @@
     <string name="alternates_for_currency_general">¢,$,€,£,¥,₱</string>
     <string name="alternates_for_smiley">":-)|:-) ,:-(|:-( ,;-)|;-) ,:-P|:-P ,=-O|=-O ,:-*|:-* ,:O|:O ,B-)|B-) ,:-$|:-$ ,:-!|:-! ,:-[|:-[ ,O:-)|O:-) ,:-\\\\\\\\|:-\\\\\\\\ ,:\'(|:\'( ,:-D|:-D "</string>
     <string name="alternates_for_punctuation">"\\,,\?,!,:,-,\',\",(,),/,;,+,&amp;,\@"</string>
-    <integer name="popup_keyboard_column_for_punctuation">7</integer>
+    <integer name="mini_keyboard_column_for_punctuation">7</integer>
     <string name="keyhintlabel_for_punctuation"></string>
     <string name="keylabel_for_popular_domain">".com"</string>
     <!-- popular web domains for the locale - most popular, displayed on the keyboard -->
diff --git a/java/res/values/styles.xml b/java/res/values/styles.xml
index 7936f3c3c6264c8a7826f8e1abee80b64202adc5..eb5b749dd718e7e35374e66edcaf450b599e46d5 100644
--- a/java/res/values/styles.xml
+++ b/java/res/values/styles.xml
@@ -21,12 +21,12 @@
         <item name="keyboardHeight">@dimen/keyboardHeight</item>
         <item name="maxKeyboardHeight">@fraction/maxKeyboardHeight</item>
         <item name="minKeyboardHeight">@fraction/minKeyboardHeight</item>
-        <item name="popupKeyboardTemplate">@xml/kbd_popup_template</item>
+        <item name="popupTemplate">@xml/kbd_mini_keyboard_template</item>
         <item name="keyboardTopPadding">@fraction/keyboard_top_padding</item>
         <item name="keyboardBottomPadding">@fraction/keyboard_bottom_padding</item>
         <item name="horizontalGap">@fraction/key_horizontal_gap</item>
         <item name="verticalGap">@fraction/key_bottom_gap</item>
-        <item name="maxPopupKeyboardColumn">@integer/config_max_popup_keyboard_column</item>
+        <item name="maxMiniKeyboardColumn">@integer/config_max_mini_keyboard_column</item>
     </style>
     <style name="LatinKeyboard">
         <item name="autoCorrectionSpacebarLedEnabled">@bool/config_auto_correction_spacebar_led_enabled
@@ -61,20 +61,20 @@
         <item name="keyPreviewOffset">@dimen/key_preview_offset</item>
         <item name="keyPreviewHeight">@dimen/key_preview_height</item>
         <item name="keyPreviewTextRatio">@fraction/key_preview_text_ratio</item>
-        <item name="popupLayout">@layout/keyboard_popup</item>
+        <item name="popupLayout">@layout/mini_keyboard</item>
         <item name="verticalCorrection">@dimen/keyboard_vertical_correction</item>
         <item name="shadowColor">#BB000000</item>
         <item name="shadowRadius">2.75</item>
         <item name="backgroundDimAmount">0.5</item>
     </style>
     <style
-        name="PopupMiniKeyboardView"
+        name="MiniKeyboardView"
         parent="KeyboardView"
     >
         <item name="keyBackground">@drawable/btn_keyboard_key_popup</item>
         <item name="verticalCorrection">@dimen/mini_keyboard_vertical_correction</item>
     </style>
-    <style name="PopupMiniKeyboardPanelStyle">
+    <style name="MiniKeyboardPanelStyle">
         <item name="android:background">@drawable/keyboard_popup_panel_background</item>
         <item name="android:paddingLeft">@dimen/mini_keyboard_horizontal_edges_padding</item>
         <item name="android:paddingRight">@dimen/mini_keyboard_horizontal_edges_padding</item>
@@ -139,8 +139,8 @@
         <item name="shadowColor">#FFFFFFFF</item>
     </style>
     <style
-        name="PopupMiniKeyboardView.Stone"
-        parent="PopupMiniKeyboardView"
+        name="MiniKeyboardView.Stone"
+        parent="MiniKeyboardView"
     >
         <item name="keyBackground">@drawable/btn_keyboard_key_stone</item>
         <item name="keyTextColor">#FF000000</item>
@@ -170,8 +170,8 @@
         <item name="keyTextStyle">bold</item>
     </style>
     <style
-        name="PopupMiniKeyboardView.Gingerbread"
-        parent="PopupMiniKeyboardView"
+        name="MiniKeyboardView.Gingerbread"
+        parent="MiniKeyboardView"
     >
         <item name="android:background">@null</item>
     </style>
@@ -213,13 +213,13 @@
         <item name="shadowRadius">0.0</item>
     </style>
     <style
-        name="PopupMiniKeyboardView.IceCreamSandwich"
-        parent="PopupMiniKeyboardView"
+        name="MiniKeyboardView.IceCreamSandwich"
+        parent="MiniKeyboardView"
     >
         <item name="android:background">@null</item>
         <item name="keyBackground">@drawable/btn_keyboard_key_popup_ics</item>
     </style>
-    <style name="PopupMiniKeyboardPanelStyle.IceCreamSandwich">
+    <style name="MiniKeyboardPanelStyle.IceCreamSandwich">
         <item name="android:background">@drawable/btn_keyboard_key_popup_background_holo</item>
         <item name="android:paddingLeft">@dimen/mini_keyboard_horizontal_edges_padding_ics</item>
         <item name="android:paddingRight">@dimen/mini_keyboard_horizontal_edges_padding_ics</item>
@@ -232,7 +232,7 @@
     </style>
     <style
         name="SuggestionPreviewBackgroundStyle.IceCreamSandwich"
-        parent="PopupMiniKeyboardPanelStyle.IceCreamSandwich"
+        parent="MiniKeyboardPanelStyle.IceCreamSandwich"
     >
     </style>
     <style
@@ -246,7 +246,7 @@
         <item name="candidateCountInStrip">@integer/candidate_count_in_strip</item>
         <item name="centerCandidatePercentile">@integer/center_candidate_percentile</item>
     </style>
-    <style name="PopupMiniKeyboardAnimation">
+    <style name="MiniKeyboardAnimation">
         <item name="android:windowEnterAnimation">@anim/mini_keyboard_fadein</item>
         <item name="android:windowExitAnimation">@anim/mini_keyboard_fadeout</item>
     </style>
diff --git a/java/res/values/themes-basic-highcontrast.xml b/java/res/values/themes-basic-highcontrast.xml
index 820f96216a535067689e0800f7f9ca0a2b26dd3e..17c06a27805e4f60714724eb68b7728092949208 100644
--- a/java/res/values/themes-basic-highcontrast.xml
+++ b/java/res/values/themes-basic-highcontrast.xml
@@ -19,8 +19,8 @@
         <item name="keyboardStyle">@style/Keyboard</item>
         <item name="latinKeyboardStyle">@style/LatinKeyboard</item>
         <item name="keyboardViewStyle">@style/KeyboardView.HighContrast</item>
-        <item name="popupMiniKeyboardViewStyle">@style/PopupMiniKeyboardView</item>
-        <item name="popupMiniKeyboardPanelStyle">@style/PopupMiniKeyboardPanelStyle</item>
+        <item name="miniKeyboardViewStyle">@style/MiniKeyboardView</item>
+        <item name="miniKeyboardPanelStyle">@style/MiniKeyboardPanelStyle</item>
         <item name="suggestionsStripBackgroundStyle">@style/SuggestionsStripBackgroundStyle</item>
         <item name="suggestionBackgroundStyle">@style/SuggestionBackgroundStyle</item>
         <item name="suggestionPreviewBackgroundStyle">@style/SuggestionPreviewBackgroundStyle</item>
diff --git a/java/res/values/themes-basic.xml b/java/res/values/themes-basic.xml
index 18cae4e24b3102ba0d1c6d94fe9b1c824f378de8..23c71bd6fd871523d0ab14c4385d371c6052dd06 100644
--- a/java/res/values/themes-basic.xml
+++ b/java/res/values/themes-basic.xml
@@ -19,8 +19,8 @@
         <item name="keyboardStyle">@style/Keyboard</item>
         <item name="latinKeyboardStyle">@style/LatinKeyboard</item>
         <item name="keyboardViewStyle">@style/KeyboardView</item>
-        <item name="popupMiniKeyboardViewStyle">@style/PopupMiniKeyboardView</item>
-        <item name="popupMiniKeyboardPanelStyle">@style/PopupMiniKeyboardPanelStyle</item>
+        <item name="miniKeyboardViewStyle">@style/MiniKeyboardView</item>
+        <item name="miniKeyboardPanelStyle">@style/MiniKeyboardPanelStyle</item>
         <item name="suggestionsStripBackgroundStyle">@style/SuggestionsStripBackgroundStyle</item>
         <item name="suggestionBackgroundStyle">@style/SuggestionBackgroundStyle</item>
         <item name="suggestionPreviewBackgroundStyle">@style/SuggestionPreviewBackgroundStyle</item>
diff --git a/java/res/values/themes-gingerbread.xml b/java/res/values/themes-gingerbread.xml
index 60f22615352ab7702e59347cc0b8cc6a634303ee..1e3419f8c5f889a8134ef9e8265b57eefa49a556 100644
--- a/java/res/values/themes-gingerbread.xml
+++ b/java/res/values/themes-gingerbread.xml
@@ -19,8 +19,8 @@
         <item name="keyboardStyle">@style/Keyboard.Gingerbread</item>
         <item name="latinKeyboardStyle">@style/LatinKeyboard</item>
         <item name="keyboardViewStyle">@style/KeyboardView.Gingerbread</item>
-        <item name="popupMiniKeyboardViewStyle">@style/PopupMiniKeyboardView.Gingerbread</item>
-        <item name="popupMiniKeyboardPanelStyle">@style/PopupMiniKeyboardPanelStyle</item>
+        <item name="miniKeyboardViewStyle">@style/MiniKeyboardView.Gingerbread</item>
+        <item name="miniKeyboardPanelStyle">@style/MiniKeyboardPanelStyle</item>
         <item name="suggestionsStripBackgroundStyle">@style/SuggestionsStripBackgroundStyle</item>
         <item name="suggestionBackgroundStyle">@style/SuggestionBackgroundStyle</item>
         <item name="suggestionPreviewBackgroundStyle">@style/SuggestionPreviewBackgroundStyle</item>
diff --git a/java/res/values/themes-ics.xml b/java/res/values/themes-ics.xml
index 97c5944082a83e988a010e112224e0ebd7f99225..7fa879cadae037d4d4245d7994fafada1e5210f8 100644
--- a/java/res/values/themes-ics.xml
+++ b/java/res/values/themes-ics.xml
@@ -19,8 +19,8 @@
         <item name="keyboardStyle">@style/Keyboard.IceCreamSandwich</item>
         <item name="latinKeyboardStyle">@style/LatinKeyboard.IceCreamSandwich</item>
         <item name="keyboardViewStyle">@style/KeyboardView.IceCreamSandwich</item>
-        <item name="popupMiniKeyboardViewStyle">@style/PopupMiniKeyboardView.IceCreamSandwich</item>
-        <item name="popupMiniKeyboardPanelStyle">@style/PopupMiniKeyboardPanelStyle.IceCreamSandwich</item>
+        <item name="miniKeyboardViewStyle">@style/MiniKeyboardView.IceCreamSandwich</item>
+        <item name="miniKeyboardPanelStyle">@style/MiniKeyboardPanelStyle.IceCreamSandwich</item>
         <item name="suggestionsStripBackgroundStyle">@style/SuggestionsStripBackgroundStyle.IceCreamSandwich</item>
         <item name="suggestionBackgroundStyle">@style/SuggestionBackgroundStyle.IceCreamSandwich</item>
         <item name="suggestionPreviewBackgroundStyle">@style/SuggestionPreviewBackgroundStyle.IceCreamSandwich</item>
diff --git a/java/res/values/themes-stone-bold.xml b/java/res/values/themes-stone-bold.xml
index d33e6bf352a67c69806118598bfa4d8f4c783453..fa2ee2dfdc68e0526784c2b49721566aac60b623 100644
--- a/java/res/values/themes-stone-bold.xml
+++ b/java/res/values/themes-stone-bold.xml
@@ -19,8 +19,8 @@
         <item name="keyboardStyle">@style/Keyboard.Stone</item>
         <item name="latinKeyboardStyle">@style/LatinKeyboard.Stone</item>
         <item name="keyboardViewStyle">@style/KeyboardView.Stone.Bold</item>
-        <item name="popupMiniKeyboardViewStyle">@style/PopupMiniKeyboardView.Stone</item>
-        <item name="popupMiniKeyboardPanelStyle">@style/PopupMiniKeyboardPanelStyle</item>
+        <item name="miniKeyboardViewStyle">@style/MiniKeyboardView.Stone</item>
+        <item name="miniKeyboardPanelStyle">@style/MiniKeyboardPanelStyle</item>
         <item name="suggestionsStripBackgroundStyle">@style/SuggestionsStripBackgroundStyle</item>
         <item name="suggestionBackgroundStyle">@style/SuggestionBackgroundStyle</item>
         <item name="suggestionPreviewBackgroundStyle">@style/SuggestionPreviewBackgroundStyle</item>
diff --git a/java/res/values/themes-stone.xml b/java/res/values/themes-stone.xml
index 230b2ca4d54fe83e428562fd86f5cefe8c21857e..494bae6006d0ec1339c142f7af3198d6294de144 100644
--- a/java/res/values/themes-stone.xml
+++ b/java/res/values/themes-stone.xml
@@ -19,8 +19,8 @@
         <item name="keyboardStyle">@style/Keyboard.Stone</item>
         <item name="latinKeyboardStyle">@style/LatinKeyboard.Stone</item>
         <item name="keyboardViewStyle">@style/KeyboardView.Stone</item>
-        <item name="popupMiniKeyboardViewStyle">@style/PopupMiniKeyboardView.Stone</item>
-        <item name="popupMiniKeyboardPanelStyle">@style/PopupMiniKeyboardPanelStyle</item>
+        <item name="miniKeyboardViewStyle">@style/MiniKeyboardView.Stone</item>
+        <item name="miniKeyboardPanelStyle">@style/MiniKeyboardPanelStyle</item>
         <item name="suggestionsStripBackgroundStyle">@style/SuggestionsStripBackgroundStyle</item>
         <item name="suggestionBackgroundStyle">@style/SuggestionBackgroundStyle</item>
         <item name="suggestionPreviewBackgroundStyle">@style/SuggestionPreviewBackgroundStyle</item>
diff --git a/java/res/xml-sw600dp/kbd_key_styles.xml b/java/res/xml-sw600dp/kbd_key_styles.xml
index b93d3007f1f90d37954a9a8032bfadee15d05983..43b6623a9bf454b2dc48a69a6b691e5d92d0f93d 100644
--- a/java/res/xml-sw600dp/kbd_key_styles.xml
+++ b/java/res/xml-sw600dp/kbd_key_styles.xml
@@ -73,7 +73,7 @@
         latin:keyOutputText=":-) "
         latin:keyLabelOption="hasPopupHint"
         latin:popupCharacters="@string/alternates_for_smiley"
-        latin:maxPopupKeyboardColumn="5" />
+        latin:maxMiniKeyboardColumn="5" />
     <key-style
         latin:styleName="shortcutKeyStyle"
         latin:code="@integer/key_shortcut"
diff --git a/java/res/xml-sw768dp/kbd_key_styles.xml b/java/res/xml-sw768dp/kbd_key_styles.xml
index 7c74bb5ad41f684cb27bff527a051de74c3d04cb..52ee91a37c472fa788f2951f23b4243ab2fbe8e9 100644
--- a/java/res/xml-sw768dp/kbd_key_styles.xml
+++ b/java/res/xml-sw768dp/kbd_key_styles.xml
@@ -55,7 +55,7 @@
         latin:keyOutputText=":-) "
         latin:keyLabelOption="hasPopupHint"
         latin:popupCharacters="@string/alternates_for_smiley"
-        latin:maxPopupKeyboardColumn="5" />
+        latin:maxMiniKeyboardColumn="5" />
     <key-style
         latin:styleName="settingsKeyStyle"
         latin:code="@integer/key_settings"
diff --git a/java/res/xml/kbd_key_styles.xml b/java/res/xml/kbd_key_styles.xml
index 48468987e5101c40a8735b6a88bdcbd4c81938a2..86f0bf24bc1121262734a0990702ce417699d84f 100644
--- a/java/res/xml/kbd_key_styles.xml
+++ b/java/res/xml/kbd_key_styles.xml
@@ -91,7 +91,7 @@
                 latin:keyOutputText=":-) "
                 latin:keyLabelOption="hasPopupHint"
                 latin:popupCharacters="@string/alternates_for_smiley"
-                latin:maxPopupKeyboardColumn="5"
+                latin:maxMiniKeyboardColumn="5"
                 latin:parentStyle="functionalKeyStyle" />
         </case>
         <case
@@ -221,6 +221,6 @@
         latin:keyHintLabel="@string/keyhintlabel_for_punctuation"
         latin:keyLabelOption="hasPopupHint"
         latin:popupCharacters="@string/alternates_for_punctuation"
-        latin:maxPopupKeyboardColumn="@integer/popup_keyboard_column_for_punctuation"
+        latin:maxMiniKeyboardColumn="@integer/mini_keyboard_column_for_punctuation"
         latin:parentStyle="functionalKeyStyle" />
 </merge>
diff --git a/java/res/xml/kbd_popup_template.xml b/java/res/xml/kbd_mini_keyboard_template.xml
similarity index 100%
rename from java/res/xml/kbd_popup_template.xml
rename to java/res/xml/kbd_mini_keyboard_template.xml
diff --git a/java/res/xml/kbd_rows_symbols.xml b/java/res/xml/kbd_rows_symbols.xml
index 75e21a002f84f4707b39044c3394ba0f65915abb..5880d52c750ac6be2b54cd0e24350d15de7708f4 100644
--- a/java/res/xml/kbd_rows_symbols.xml
+++ b/java/res/xml/kbd_rows_symbols.xml
@@ -106,7 +106,7 @@
         <Key
             latin:keyLabel="&quot;"
             latin:popupCharacters="“,”,«,»"
-            latin:maxPopupKeyboardColumn="6" />
+            latin:maxMiniKeyboardColumn="6" />
         <Key
             latin:keyLabel="\'"
             latin:popupCharacters="‘,’,‚,‛" />
diff --git a/java/src/com/android/inputmethod/keyboard/Key.java b/java/src/com/android/inputmethod/keyboard/Key.java
index 9cf64e1512dd2f703f2b892c17ecf25ee4b7f6e4..8baf3f7d1d6e2623fd79dcd4796b0689f047b2ff 100644
--- a/java/src/com/android/inputmethod/keyboard/Key.java
+++ b/java/src/com/android/inputmethod/keyboard/Key.java
@@ -93,7 +93,7 @@ public class Key {
     /** Popup characters */
     public final CharSequence[] mPopupCharacters;
     /** Popup keyboard maximum column number */
-    public final int mMaxPopupColumn;
+    public final int mMaxMiniKeyboardColumn;
 
     /**
      * Flags that specify the anchoring to edges of the keyboard for detecting touch events
@@ -228,7 +228,7 @@ public class Key {
         mSticky = false;
         mRepeatable = false;
         mPopupCharacters = null;
-        mMaxPopupColumn = 0;
+        mMaxMiniKeyboardColumn = 0;
         mLabel = label;
         mOutputText = outputText;
         mCode = code;
@@ -323,9 +323,9 @@ public class Key {
             } else {
                 mPopupCharacters = popupCharacters;
             }
-            mMaxPopupColumn = style.getInt(keyboardAttr,
-                    R.styleable.Keyboard_Key_maxPopupKeyboardColumn,
-                    params.mMaxPopupColumn);
+            mMaxMiniKeyboardColumn = style.getInt(keyboardAttr,
+                    R.styleable.Keyboard_Key_maxMiniKeyboardColumn,
+                    params.mMaxMiniKeyboardColumn);
 
             mRepeatable = style.getBoolean(keyAttr, R.styleable.Keyboard_Key_isRepeatable, false);
             mFunctional = style.getBoolean(keyAttr, R.styleable.Keyboard_Key_isFunctional, false);
diff --git a/java/src/com/android/inputmethod/keyboard/KeyboardView.java b/java/src/com/android/inputmethod/keyboard/KeyboardView.java
index 9e5e209531716a8717add4907271fc2642809f12..4c5c2bc1073b86079340ff0f3dfc7e4aeaab5bc1 100644
--- a/java/src/com/android/inputmethod/keyboard/KeyboardView.java
+++ b/java/src/com/android/inputmethod/keyboard/KeyboardView.java
@@ -35,7 +35,6 @@ import android.util.TypedValue;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
-import android.view.ViewGroup.LayoutParams;
 import android.widget.RelativeLayout;
 import android.widget.TextView;
 
@@ -78,7 +77,9 @@ public class KeyboardView extends View implements PointerTracker.DrawingProxy {
     // Miscellaneous constants
     private static final int[] LONG_PRESSABLE_STATE_SET = { android.R.attr.state_long_pressable };
 
-    // XML attribute
+    // XML attributes
+    protected final float mVerticalCorrection;
+    protected final int mPopupLayout;
     private final float mBackgroundDimAmount;
 
     // HORIZONTAL ELLIPSIS "...", character for popup hint.
@@ -340,6 +341,9 @@ public class KeyboardView extends View implements PointerTracker.DrawingProxy {
         if (mKeyPreviewLayoutId == 0) {
             mShowKeyPreviewPopup = false;
         }
+        mVerticalCorrection = a.getDimensionPixelOffset(
+                R.styleable.KeyboardView_verticalCorrection, 0);
+        mPopupLayout = a.getResourceId(R.styleable.KeyboardView_popupLayout, 0);
         mBackgroundDimAmount = a.getFloat(R.styleable.KeyboardView_backgroundDimAmount, 0.5f);
         a.recycle();
 
diff --git a/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java b/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java
index 85084847d043c442bad81b0104e60f84da029a60..1e7ec9eadb04f0600112637ccc78bf70f422ce22 100644
--- a/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java
+++ b/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java
@@ -19,7 +19,6 @@ package com.android.inputmethod.keyboard;
 import android.content.Context;
 import android.content.pm.PackageManager;
 import android.content.res.Resources;
-import android.content.res.TypedArray;
 import android.graphics.Canvas;
 import android.os.Message;
 import android.os.SystemClock;
@@ -64,10 +63,6 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
     // Timing constants
     private final int mKeyRepeatInterval;
 
-    // XML attribute
-    private final float mVerticalCorrection;
-    private final int mPopupLayout;
-
     // Mini keyboard
     private PopupWindow mPopupWindow;
     private PopupPanel mPopupPanel;
@@ -219,13 +214,6 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
 
         mTouchScreenRegulator = new SuddenJumpingTouchEventHandler(getContext(), this);
 
-        final TypedArray a = context.obtainStyledAttributes(
-                attrs, R.styleable.KeyboardView, defStyle, R.style.KeyboardView);
-        mVerticalCorrection = a.getDimensionPixelOffset(
-                R.styleable.KeyboardView_verticalCorrection, 0);
-        mPopupLayout = a.getResourceId(R.styleable.KeyboardView_popupLayout, 0);
-        a.recycle();
-
         final Resources res = getResources();
         mConfigShowMiniKeyboardAtTouchedPoint = res.getBoolean(
                 R.bool.config_show_mini_keyboard_at_touched_point);
@@ -374,11 +362,11 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
         if (container == null)
             throw new NullPointerException();
 
-        final PopupMiniKeyboardView miniKeyboardView =
-                (PopupMiniKeyboardView)container.findViewById(R.id.mini_keyboard_view);
+        final MiniKeyboardView miniKeyboardView =
+                (MiniKeyboardView)container.findViewById(R.id.mini_keyboard_view);
         final Keyboard parentKeyboard = getKeyboard();
         final Keyboard miniKeyboard = new MiniKeyboard.Builder(
-                this, parentKeyboard.mPopupKeyboardResId, parentKey, parentKeyboard).build();
+                this, parentKeyboard.mPopupTemplateId, parentKey, parentKeyboard).build();
         miniKeyboardView.setKeyboard(miniKeyboard);
         container.measure(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
 
@@ -454,7 +442,7 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
         if (mPopupWindow == null) {
             mPopupWindow = new PopupWindow(getContext());
             mPopupWindow.setBackgroundDrawable(null);
-            mPopupWindow.setAnimationStyle(R.style.PopupMiniKeyboardAnimation);
+            mPopupWindow.setAnimationStyle(R.style.MiniKeyboardAnimation);
             // Allow popup window to be drawn off the screen.
             mPopupWindow.setClippingEnabled(false);
         }
diff --git a/java/src/com/android/inputmethod/keyboard/MiniKeyboard.java b/java/src/com/android/inputmethod/keyboard/MiniKeyboard.java
index e6045dc90a811d57d96afe3caff73724c82ffebe..6119fa232de7be91a56aebc4b8b5f9cf8f280b57 100644
--- a/java/src/com/android/inputmethod/keyboard/MiniKeyboard.java
+++ b/java/src/com/android/inputmethod/keyboard/MiniKeyboard.java
@@ -227,8 +227,8 @@ public class MiniKeyboard extends Keyboard {
             mPopupCharacters = parentKey.mPopupCharacters;
 
             final int keyWidth = getMaxKeyWidth(view, mPopupCharacters, mParams.mDefaultKeyWidth);
-            mParams.setParameters(mPopupCharacters.length, parentKey.mMaxPopupColumn, keyWidth,
-                    parentKeyboard.mDefaultRowHeight, parentKey.mX
+            mParams.setParameters(mPopupCharacters.length, parentKey.mMaxMiniKeyboardColumn,
+                    keyWidth, parentKeyboard.mDefaultRowHeight, parentKey.mX
                             + (mParams.mDefaultKeyWidth - keyWidth) / 2, view.getMeasuredWidth());
         }
 
diff --git a/java/src/com/android/inputmethod/keyboard/PopupMiniKeyboardView.java b/java/src/com/android/inputmethod/keyboard/MiniKeyboardView.java
similarity index 96%
rename from java/src/com/android/inputmethod/keyboard/PopupMiniKeyboardView.java
rename to java/src/com/android/inputmethod/keyboard/MiniKeyboardView.java
index 7ace46cacac1428bbe3ccc990dc34538b8c0a837..065970f621c6d8d88126a62c3ea1701411981e24 100644
--- a/java/src/com/android/inputmethod/keyboard/PopupMiniKeyboardView.java
+++ b/java/src/com/android/inputmethod/keyboard/MiniKeyboardView.java
@@ -34,7 +34,7 @@ import java.util.List;
  * A view that renders a virtual {@link MiniKeyboard}. It handles rendering of keys and detecting
  * key presses and touch movements.
  */
-public class PopupMiniKeyboardView extends KeyboardView implements PopupPanel {
+public class MiniKeyboardView extends KeyboardView implements PopupPanel {
     private final int[] mCoordinates = new int[2];
 
     private final KeyDetector mKeyDetector;
@@ -128,11 +128,11 @@ public class PopupMiniKeyboardView extends KeyboardView implements PopupPanel {
         }
     };
 
-    public PopupMiniKeyboardView(Context context, AttributeSet attrs) {
-        this(context, attrs, R.attr.popupMiniKeyboardViewStyle);
+    public MiniKeyboardView(Context context, AttributeSet attrs) {
+        this(context, attrs, R.attr.miniKeyboardViewStyle);
     }
 
-    public PopupMiniKeyboardView(Context context, AttributeSet attrs, int defStyle) {
+    public MiniKeyboardView(Context context, AttributeSet attrs, int defStyle) {
         super(context, attrs, defStyle);
 
         final TypedArray a = context.obtainStyledAttributes(
diff --git a/java/src/com/android/inputmethod/keyboard/internal/KeyStyles.java b/java/src/com/android/inputmethod/keyboard/internal/KeyStyles.java
index c0dba4173ca00f8ef5e629ad490afd1ad6fa191d..66dde0512e82c559104e4f63ee3ee213b3c47c81 100644
--- a/java/src/com/android/inputmethod/keyboard/internal/KeyStyles.java
+++ b/java/src/com/android/inputmethod/keyboard/internal/KeyStyles.java
@@ -171,7 +171,7 @@ public class KeyStyles {
             readInt(keyAttr, R.styleable.Keyboard_Key_keyIcon);
             readInt(keyAttr, R.styleable.Keyboard_Key_keyIconPreview);
             readInt(keyAttr, R.styleable.Keyboard_Key_keyIconShifted);
-            readInt(keyAttr, R.styleable.Keyboard_Key_maxPopupKeyboardColumn);
+            readInt(keyAttr, R.styleable.Keyboard_Key_maxMiniKeyboardColumn);
             readBoolean(keyAttr, R.styleable.Keyboard_Key_isFunctional);
             readBoolean(keyAttr, R.styleable.Keyboard_Key_isSticky);
             readBoolean(keyAttr, R.styleable.Keyboard_Key_isRepeatable);
diff --git a/java/src/com/android/inputmethod/keyboard/internal/KeyboardBuilder.java b/java/src/com/android/inputmethod/keyboard/internal/KeyboardBuilder.java
index f599def36a9ae565aed0ff4a8ccc499f5a370937..5c76facec640e189f50d61a42d392d1483267a9c 100644
--- a/java/src/com/android/inputmethod/keyboard/internal/KeyboardBuilder.java
+++ b/java/src/com/android/inputmethod/keyboard/internal/KeyboardBuilder.java
@@ -255,10 +255,10 @@ public class KeyboardBuilder<KP extends KeyboardParams> {
 
             mParams.mIsRtlKeyboard = keyboardAttr.getBoolean(
                     R.styleable.Keyboard_isRtlKeyboard, false);
-            mParams.mPopupKeyboardResId = keyboardAttr.getResourceId(
-                    R.styleable.Keyboard_popupKeyboardTemplate, 0);
-            mParams.mMaxPopupColumn = keyAttr.getInt(
-                    R.styleable.Keyboard_Key_maxPopupKeyboardColumn, 5);
+            mParams.mPopupTemplateId = keyboardAttr.getResourceId(
+                    R.styleable.Keyboard_popupTemplate, 0);
+            mParams.mMaxMiniKeyboardColumn = keyAttr.getInt(
+                    R.styleable.Keyboard_Key_maxMiniKeyboardColumn, 5);
 
             mParams.mIconsSet.loadIcons(keyboardAttr);
         } finally {
diff --git a/java/src/com/android/inputmethod/keyboard/internal/KeyboardParams.java b/java/src/com/android/inputmethod/keyboard/internal/KeyboardParams.java
index 980115200ce45774f388d64fb81da2ea22678468..e748dbb943f030ca0ab18f93e107640893223485 100644
--- a/java/src/com/android/inputmethod/keyboard/internal/KeyboardParams.java
+++ b/java/src/com/android/inputmethod/keyboard/internal/KeyboardParams.java
@@ -49,8 +49,8 @@ public class KeyboardParams {
     public int mVerticalGap;
 
     public boolean mIsRtlKeyboard;
-    public int mPopupKeyboardResId;
-    public int mMaxPopupColumn;
+    public int mPopupTemplateId;
+    public int mMaxMiniKeyboardColumn;
 
     public int GRID_WIDTH;
     public int GRID_HEIGHT;
diff --git a/java/src/com/android/inputmethod/keyboard/Keyboard.java b/java/src/com/android/inputmethod/keyboard/Keyboard.java
index f8e08b06a796053b1a941874ef591ac20888bfbc..5dabb93ec8b767075e2c7db42fa644f61af415c5 100644
--- a/java/src/com/android/inputmethod/keyboard/Keyboard.java
+++ b/java/src/com/android/inputmethod/keyboard/Keyboard.java
@@ -102,10 +102,10 @@ public class Keyboard {
     public final int mMostCommonKeyWidth;
 
     /** Popup keyboard template */
-    public final int mPopupKeyboardResId;
+    public final int mPopupTemplateId;
 
-    /** Maximum column for popup keyboard */
-    public final int mMaxPopupColumn;
+    /** Maximum column for mini keyboard */
+    public final int mMaxMiniKeyboardColumn;
 
     /** True if Right-To-Left keyboard */
     public final boolean mIsRtlKeyboard;
@@ -130,8 +130,8 @@ public class Keyboard {
         mWidth = params.mWidth;
         mMostCommonKeyWidth = params.mMostCommonKeyWidth;
         mIsRtlKeyboard = params.mIsRtlKeyboard;
-        mPopupKeyboardResId = params.mPopupKeyboardResId;
-        mMaxPopupColumn = params.mMaxPopupColumn;
+        mPopupTemplateId = params.mPopupTemplateId;
+        mMaxMiniKeyboardColumn = params.mMaxMiniKeyboardColumn;
 
         mDefaultRowHeight = params.mDefaultRowHeight;
         mVerticalGap = params.mVerticalGap;